"""Increase number of characters for keywords metadata

Revision ID: 3dce903da79a
Revises: 7866a83369ff
Create Date: 2019-11-11 17:08:28.147825+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '3dce903da79a'
down_revision = '7866a83369ff'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('python_package_metadata', sa.Column('keywords', sa.String(length=512), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('python_package_metadata', sa.Column('keywords', sa.String(length=256), nullable=True))
    # ### end Alembic commands ###
